### Eclipse Workspace Patch 1.0
#P drupalit
Index: drupalit.js
===================================================================
RCS file: /cvs/drupal-contrib/contributions/modules/drupalit/drupalit.js,v
retrieving revision 1.1
diff -u -r1.1 drupalit.js
--- drupalit.js	24 Apr 2007 17:44:42 -0000	1.1
+++ drupalit.js	28 Apr 2007 07:55:51 -0000
@@ -1,10 +1,10 @@
 // $Id: drupalit.js,v 1.1 2007/04/24 17:44:42 tic2000 Exp $
 
 Drupal.drupalit = function() {
-  var vdb = [];
+  var dvdb = [];
   $('div.vote-wrap').each(function () {
     // Read in the path to the PHP handler	
-    uri = $(this).children('a').attr('href');
+    duri = $(this).children('a').attr('href');
     // Remove the title, so no tooltip will display
     $(this).removeAttr('title');
 	// remove href link
@@ -12,36 +12,36 @@
     // Create an object with this uri. Because
     // we feed in the div as an argument, we'll be able
     // to attach events to this element.
-    if (!vdb[uri]) {
-      vdb[uri] = new Drupal.VDB(this, uri);
+    if (!dvdb[uri]) {
+      dvdb[uri] = new Drupal.DVDB(this, duri);
     }
   });
 }
 
 /**
- * A Vote DataBase object
+ * A Drupalit Vote DataBase object
  */
-Drupal.VDB = function(elt, uri, id) {
-  var db = this;
+Drupal.DVDB = function(delt, duri, did) {
+  var ddb = this;
   // By making the span element a property of this object,
   // we get the ability to attach behaviours to that element.
-  this.elt = elt;
-  this.uri = uri;
-  this.id = $(elt).attr('id');
-  $(elt).children('a').click(function() {
+  this.delt = delt;
+  this.duri = duri;
+  this.did = $(delt).attr('id');
+  $(delt).children('a').click(function() {
     // Ajax GET request for vote data
     $.ajax({
       type: "GET",
-      url: db.uri,
-      success: function (data) {
-        // extract the cid so we can change other elements for the same cid
-        var cid = db.id.match(/[0-9]+$/);
-        var pid = 'vote-wrap-' + cid;
+      url: ddb.duri,
+      success: function (ddata) {
+        // extract the dcid so we can change other elements for the same dcid
+        var dcid = ddb.did.match(/[0-9]+$/);
+        var dpid = 'vote-wrap-' + dcid;
         // update the points
-        $('#' + pid).html(data);
+        $('#' + dpid).html(ddata);
       },
       error: function (xmlhttp) {
-        alert('An HTTP error '+ xmlhttp.status +' occured.\n'+ db.uri);
+        alert('An HTTP error '+ xmlhttp.status +' occured.\n'+ ddb.duri);
       }
     });
   });
